@@ -1,5 +1,5 @@
 # -*- perl -*-
-# $Id: UserAgent.pm,v 1.20 2000/04/20 14:49:17 langhein Exp $
+# $Id: UserAgent.pm,v 1.21 2000/05/08 13:02:29 langhein Exp $
 # derived from: UserAgent.pm,v 1.66 1999/03/20 07:37:36 gisle Exp $
 #         and:  ParallelUA.pm,v 1.16 1997/07/23 16:45:09 ahoy Exp $
 
@@ -69,6 +69,8 @@ sub AUTOLOAD {
     }
 }
 
+sub DESTROY { };
+
 package LWP::Parallel::UserAgent;
 
 use Exporter();
@@ -408,7 +410,9 @@ sub register {
 
   # so far Parallel::UserAgent can handle only http and ftp requests
   # (anybody volunteering to porting the rest of the protocols?!)
-  unless ( $request->url->scheme eq 'http' or $request->url->scheme eq 'ftp' ){
+  unless ( $request->url->scheme eq 'http' or $request->url->scheme eq 'ftp'
+           # https suggestion by <mszabo@coralwave.com>
+           or $request->url->scheme eq 'https' ){
     $response->code (&HTTP::Status::RC_NOT_IMPLEMENTED);
     $response->message ("Unknown Scheme: ". $request->url->scheme);
     Carp::carp "Parallel::UserAgent can not handle '". $request->url->scheme .
